import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.cloud_assembly_schema._jsii
import aws_cdk.cx_api._jsii
import aws_cdk.region_info._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/core", "1.68.0", __name__[0:-6], "core@1.68.0.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
